# Generated by Django 3.2.24 on 2025-07-07 08:37

# Django
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("django_easy_quiz", "0008_auto_20250707_1029"),
    ]

    operations = [
        migrations.AddField(
            model_name="moreinfoquestion",
            name="is_required",
            field=models.BooleanField(
                default=False, help_text="Is this question required?"
            ),
        ),
    ]



# Generated by Django 3.2.24 on 2025-07-07 08:29

# Django
from django.db import migrations, models

# Third party
import ckeditor_uploader.fields


class Migration(migrations.Migration):

    dependencies = [
        ("django_easy_quiz", "0007_auto_20240624_1144"),
    ]

    operations = [
        migrations.AddField(
            model_name="weightedanswersquizquestion",
            name="answer_10",
            field=ckeditor_uploader.fields.RichTextUploadingField(
                blank=True, null=True, verbose_name="Answer 10"
            ),
        ),
        migrations.AddField(
            model_name="weightedanswersquizquestion",
            name="answer_7",
            field=ckeditor_uploader.fields.RichTextUploadingField(
                blank=True, null=True, verbose_name="Answer 7"
            ),
        ),
        migrations.AddField(
            model_name="weightedanswersquizquestion",
            name="answer_8",
            field=ckeditor_uploader.fields.RichTextUploadingField(
                blank=True, null=True, verbose_name="Answer 8"
            ),
        ),
        migrations.AddField(
            model_name="weightedanswersquizquestion",
            name="answer_9",
            field=ckeditor_uploader.fields.RichTextUploadingField(
                blank=True, null=True, verbose_name="Answer 9"
            ),
        ),
        migrations.AddField(
            model_name="weightedanswersquizquestion",
            name="points_answer_10",
            field=models.IntegerField(
                blank=True, null=True, verbose_name="Points for answer 10"
            ),
        ),
        migrations.AddField(
            model_name="weightedanswersquizquestion",
            name="points_answer_7",
            field=models.IntegerField(
                blank=True, null=True, verbose_name="Points for answer 7"
            ),
        ),
        migrations.AddField(
            model_name="weightedanswersquizquestion",
            name="points_answer_8",
            field=models.IntegerField(
                blank=True, null=True, verbose_name="Points for answer 8"
            ),
        ),
        migrations.AddField(
            model_name="weightedanswersquizquestion",
            name="points_answer_9",
            field=models.IntegerField(
                blank=True, null=True, verbose_name="Points for answer 9"
            ),
        ),
        migrations.AlterField(
            model_name="interpretationquiz",
            name="answers_random",
            field=models.BooleanField(
                default=False,
                help_text="Les réponses vont être affichées dans un ordre aléatoire.",
                verbose_name="Réponses aléatoires",
            ),
        ),
        migrations.AlterField(
            model_name="interpretationquiz",
            name="questions_random",
            field=models.BooleanField(
                default=False,
                help_text="Les questions vont être affichées dans un ordre aléatoire.",
                verbose_name="Questions aléatoires",
            ),
        ),
        migrations.AlterField(
            model_name="weightedanswersquiz",
            name="answers_random",
            field=models.BooleanField(
                default=False,
                help_text="Les réponses vont être affichées dans un ordre aléatoire.",
                verbose_name="Réponses aléatoires",
            ),
        ),
        migrations.AlterField(
            model_name="weightedanswersquiz",
            name="questions_random",
            field=models.BooleanField(
                default=False,
                help_text="Les questions vont être affichées dans un ordre aléatoire.",
                verbose_name="Questions aléatoires",
            ),
        ),
        migrations.AlterField(
            model_name="weightedanswersquizquestion",
            name="multiple_answers",
            field=models.BooleanField(
                default=False, verbose_name="Plus d’une réponse possible"
            ),
        ),
    ]



# Generated by Django 3.2.24 on 2024-06-24 09:44

# Django
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("django_easy_quiz", "0006_weightedanswersquiz_show_score_summary"),
    ]

    operations = [
        migrations.AddField(
            model_name="interpretationquiz",
            name="answers_random",
            field=models.BooleanField(
                default=False,
                help_text="Answers will be shown on random order.",
                verbose_name="Random answers",
            ),
        ),
        migrations.AddField(
            model_name="weightedanswersquiz",
            name="answers_random",
            field=models.BooleanField(
                default=False,
                help_text="Answers will be shown on random order.",
                verbose_name="Random answers",
            ),
        ),
        migrations.AlterField(
            model_name="interpretationquiz",
            name="questions_random",
            field=models.BooleanField(
                default=False,
                help_text="Questions will be shown on random order.",
                verbose_name="Questions aléatoires",
            ),
        ),
        migrations.AlterField(
            model_name="weightedanswersquiz",
            name="questions_random",
            field=models.BooleanField(
                default=False,
                help_text="Questions will be shown on random order.",
                verbose_name="Questions aléatoires",
            ),
        ),
        migrations.AlterField(
            model_name="weightedanswersquiz",
            name="show_score_summary",
            field=models.BooleanField(
                default=True, verbose_name="Afficher le score dans la conclusion"
            ),
        ),
    ]
